==> cloud-pipelines-components-0.0.0.1.tar.gz: cloud-pipelines-components-0.0.0.1/setup.py <==
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import re
from setuptools import setup, find_packages


NAME = 'cloud-pipelines-components'
VERSION = '0.0.0.1'
REQUIRES = [
    'PyYAML',
    'cloudpickle',
    'Deprecated',
    'strip-hints>=0.1.8',
]

setup(
    name=NAME,
    version=VERSION,
    description='Cloud Pipelines - Components SDK',
    author='Cloud Pipelines',
    license="Apache 2.0",
    url="https://github.com/cloud-pipelines/components",
    install_requires=REQUIRES,
    package_dir={'cloud_pipelines.components': 'src'},
    packages=[
        'cloud_pipelines.components',
        'cloud_pipelines.components.structures',
        'cloud_pipelines.components.structures.kubernetes',
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
    ],
    python_requires='>=3.5.3',
    include_package_data=True,
)

==> cloud-pipelines-components-1.0.0.tar.gz: cloud-pipelines-components-1.0.0/setup.py <==
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import re
from setuptools import setup


NAME = 'cloud-pipelines-components'
VERSION = '1.0.0'
REQUIRES = [
    'cloudpickle',
    'PyYAML',
    'requests',
    'strip-hints>=0.1.8',
]
TEST_REQUIRES = [
    'mock',
]
setup(
    name=NAME,
    version=VERSION,
    description='Cloud Pipelines - Components SDK',
    author='Cloud Pipelines',
    license="Apache 2.0",
    url="https://github.com/cloud-pipelines/components",
    install_requires=REQUIRES,
    test_requires=TEST_REQUIRES,
    #package_dir={'cloud_pipelines.components': 'cloud_pipelines/components'},
    packages=[
        'cloud_pipelines.components',
        'cloud_pipelines.components.structures',
    ],
    namespace_packages=['cloud_pipelines'],
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
    ],
    python_requires='>=3.5.3',
    include_package_data=True,
)
